package com.ruoyi.config.service;

import java.util.List;
import com.ruoyi.config.domain.MeetingConfig;

/**
 * 视频会议配置Service接口
 * 
 * @author ruoyi
 * @date 2023-04-18
 */
public interface IMeetingConfigService 
{
    /**
     * 查询视频会议配置
     * 
     * @param id 视频会议配置主键
     * @return 视频会议配置
     */
    public MeetingConfig selectMeetingConfigById(Long id);

    /**
     * 查询视频会议配置列表
     * 
     * @param meetingConfig 视频会议配置
     * @return 视频会议配置集合
     */
    public List<MeetingConfig> selectMeetingConfigList(MeetingConfig meetingConfig);

    /**
     * 新增视频会议配置
     * 
     * @param meetingConfig 视频会议配置
     * @return 结果
     */
    public int insertMeetingConfig(MeetingConfig meetingConfig);

    /**
     * 修改视频会议配置
     * 
     * @param meetingConfig 视频会议配置
     * @return 结果
     */
    public int updateMeetingConfig(MeetingConfig meetingConfig);

    /**
     * 批量删除视频会议配置
     * 
     * @param ids 需要删除的视频会议配置主键集合
     * @return 结果
     */
    public int deleteMeetingConfigByIds(String ids);

    /**
     * 删除视频会议配置信息
     * 
     * @param id 视频会议配置主键
     * @return 结果
     */
    public int deleteMeetingConfigById(Long id);
}
