package com.ruoyi.config.controller;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.config.domain.MeetingConfig;
import com.ruoyi.config.service.IMeetingConfigService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 视频会议配置Controller
 * 
 * @author ruoyi
 * @date 2023-04-18
 */
@Controller
@RequestMapping("/config/config")
public class MeetingConfigController extends BaseController
{
    private String prefix = "config/config";

    @Autowired
    private IMeetingConfigService meetingConfigService;

    @RequiresPermissions("config:config:view")
    @GetMapping()
    public String config()
    {
        return prefix + "/config";
    }

    /**
     * 查询视频会议配置列表
     */
    @RequiresPermissions("config:config:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(MeetingConfig meetingConfig)
    {
        startPage();
        List<MeetingConfig> list = meetingConfigService.selectMeetingConfigList(meetingConfig);
        return getDataTable(list);
    }

    /**
     * 导出视频会议配置列表
     */
    @RequiresPermissions("config:config:export")
    @Log(title = "视频会议配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(MeetingConfig meetingConfig)
    {
        List<MeetingConfig> list = meetingConfigService.selectMeetingConfigList(meetingConfig);
        ExcelUtil<MeetingConfig> util = new ExcelUtil<MeetingConfig>(MeetingConfig.class);
        return util.exportExcel(list, "视频会议配置数据");
    }

    /**
     * 新增视频会议配置
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存视频会议配置
     */
    @RequiresPermissions("config:config:add")
    @Log(title = "视频会议配置", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(MeetingConfig meetingConfig)
    {
        return toAjax(meetingConfigService.insertMeetingConfig(meetingConfig));
    }

    /**
     * 修改视频会议配置
     */
    @RequiresPermissions("config:config:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        MeetingConfig meetingConfig = meetingConfigService.selectMeetingConfigById(id);
        mmap.put("meetingConfig", meetingConfig);
        return prefix + "/edit";
    }

    /**
     * 修改保存视频会议配置
     */
    @RequiresPermissions("config:config:edit")
    @Log(title = "视频会议配置", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(MeetingConfig meetingConfig)
    {
        return toAjax(meetingConfigService.updateMeetingConfig(meetingConfig));
    }

    /**
     * 删除视频会议配置
     */
    @RequiresPermissions("config:config:remove")
    @Log(title = "视频会议配置", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(meetingConfigService.deleteMeetingConfigByIds(ids));
    }
}
